#[non_exhaustive]
pub struct DataSource { pub id: Base64Uuid, pub name: Name, pub proxy_name: Option<Name>, pub provider_type: String, pub protocol_version: u8, pub description: Option<String>, pub config: Option<Map<String, Value>>, pub status: Option<DataSourceStatus>, pub created_at: Timestamp, pub updated_at: Timestamp, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Base64Uuid

Data source ID.

name: Name

Name of the data source.

Data source names do not need to be unique per workspace, but they are unique per proxy.

proxy_name: Option<Name>

Optional name of the FPD instance through which requests to the data source should be proxied. This is None for direct data sources.

provider_type: String

The type of provider used for querying the data source.

protocol_version: u8

Protocol version supported by the provider.

description: Option<String>

Optional human-friendly description of the data source.

config: Option<Map<String, Value>>

Optional configuration for the data source. If the data source is proxied through an FPD instance, the config will not be exposed to outside clients.

status: Option<DataSourceStatus>

The data source status as reported by the FPD instance. Will be None for direct data sources.

created_at: Timestamp

Timestamp at which the data source was created.

updated_at: Timestamp

Timestamp at which the data source or its config was last updated.

Implementations

source

impl DataSource

source

pub fn builder() -> DataSourceBuilder<((), (), (), (), (), (), (), (), (), ())>

Create a builder for building DataSource. On the builder, call .id(...), .name(...), .proxy_name(...)(optional), .provider_type(...), .protocol_version(...)(optional), .description(...)(optional), .config(...)(optional), .status(...)(optional), .created_at(...), .updated_at(...) to set the values of the fields. Finally, call .build() to create the instance of DataSource.