Enum fiberplane_models::formatting::Annotation
source · #[non_exhaustive]
pub enum Annotation {
Show 17 variants
StartBold,
EndBold,
StartCode,
EndCode,
StartHighlight,
EndHighlight,
StartItalics,
EndItalics,
StartLink {
url: String,
},
EndLink,
Mention(Mention),
Timestamp {
timestamp: OffsetDateTime,
},
StartStrikethrough,
EndStrikethrough,
StartUnderline,
EndUnderline,
Label(Label),
}Expand description
A rich-text annotation.
Annotations are typically found inside a Formatting vector.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StartBold
EndBold
StartCode
EndCode
StartHighlight
EndHighlight
StartItalics
EndItalics
StartLink
EndLink
Mention(Mention)
Timestamp
Fields

timestamp: OffsetDateTimeStartStrikethrough
EndStrikethrough
StartUnderline
EndUnderline
Label(Label)
Implementations
sourceimpl Annotation
impl Annotation
sourcepub fn toggle_opposite(&self) -> Option<Annotation>
pub fn toggle_opposite(&self) -> Option<Annotation>
Returns the opposite of an annotation for the purpose of toggling the formatting.
Returns None if the annotation is not part of a pair, or if the
formatting cannot be toggled without more information.