Formatting

Type Alias Formatting 

pub type Formatting = Vec<AnnotationWithOffset>;
Formatting to be applied in order to turn plain-text into rich-text.

The vector consists of tuples, each containing a character offset and an annotation. The vector must be sorted by offset (the order of annotations at the same offset is undefined).

Aliased Type

pub struct Formatting { /* private fields */ }