TableRowValue

Enum TableRowValue 

#[non_exhaustive]
pub enum TableRowValue { Text(RichText), }
One of the values stored in a TableRow.

We intentionally avoid the term “cell” here, because it would be too confusing with the table cell itself.

Row values can be looked up by ID, although the ID is not stored in the row value itself. Instead, it can be created from the row ID and column ID.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.