NotebookCellsAppendQuery

Struct NotebookCellsAppendQuery 

#[non_exhaustive]
pub struct NotebookCellsAppendQuery { pub before: Option<String>, pub after: Option<String>, }
The query string values that are associated with the notebook_cells_append endpoint.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
before: Option<String>

Append the provided cells before this cell. If the cell is not found it will return a 400. This parameter cannot be used together with after.

after: Option<String>

Append the provided cells after this cell. If the cell is not found it will return a 400. This parameter cannot be used together with before.

Implementations

Source

impl NotebookCellsAppendQuery

pub fn builder() -> NotebookCellsAppendQueryBuilder<((), ())>

Create a builder for building NotebookCellsAppendQuery. On the builder, call .before(...)(optional), .after(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of NotebookCellsAppendQuery.