Struct fiberplane_models::notebooks::TableColumnId
source · pub struct TableColumnId(/* private fields */);Expand description
This is an automatically generated ID that is added to every column in a table cell.
Table column IDs are used to refer to column definitions in the table. They can also be combined with a TableRowId to create a [TableRowItemId].
Column IDs may only contain alphanumeric characters and must be unique within a table.