#[non_exhaustive]pub struct IntegerField {
pub name: String,
pub label: String,
pub max: Option<i32>,
pub min: Option<i32>,
pub placeholder: String,
pub required: bool,
pub step: Option<i32>,
}Expand description
Defines a field that allows integer numbers to be entered.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of the field as it will be included in the encoded query or config object.
label: StringSuggested label to display along the field.
max: Option<i32>Optional maximum value to be entered.
min: Option<i32>Optional minimal value to be entered.
placeholder: StringSuggested placeholder to display when there is no value.
required: boolWhether a value is required.
step: Option<i32>Specifies the granularity that any specified numbers must adhere to.
If omitted, step defaults to “1”, meaning only integers are allowed.
Implementations
Sourceimpl IntegerField
impl IntegerField
Sourcepub fn with_bounds(self, min: i32, max: i32) -> Self
pub fn with_bounds(self, min: i32, max: i32) -> Self
Convenience method for setting min and max together.
pub fn with_label(self, label: impl Into<String>) -> Self
pub fn with_max(self, max: i32) -> Self
pub fn with_min(self, min: i32) -> Self
pub fn with_name(self, name: impl Into<String>) -> Self
pub fn with_step(self, step: i32) -> Self