#[non_exhaustive]pub struct LabelField {
pub name: String,
pub label: String,
pub multiple: bool,
pub placeholder: String,
pub required: bool,
}Expand description
Defines a field that allows labels to be selected.
For JSON/YAML encoding, the value will be represented as a string or an
array of strings, depending on the value of the multiple field. In the
case of “application/x-www-form-urlencoded”, the value is always a single
string and multiple labels will be space-separated.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of the field as it will be included in the encoded query or config object.
label: StringSuggested label to display along the field (not to be confused with labels to be selected).
multiple: boolWhether multiple labels may be selected.
placeholder: StringSuggested placeholder to display when there is no value.
required: boolWhether a value is required.
Implementations
Sourceimpl LabelField
impl LabelField