#[non_exhaustive]
pub struct ProviderStatus { pub status: Result<(), Error>, pub version: String, pub built_at: String, }
Response type for status requests.

To be serialized using the application/vnd.fiberplane.provider-status MIME type.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
status: Result<(), Error>

Indicates whether the provider is available to be queried.

version: String

Version string of the provider.

Arbitrary strings may be used, such as commit hashes, but release versions of providers are expected to report semver versions.

built_at: String

Human-readable timestamp at which the provider was built.

Only used for diagnostics.

Implementations

source

impl ProviderStatus

source

pub fn builder() -> ProviderStatusBuilder<((), (), ())>

Create a builder for building ProviderStatus. On the builder, call .status(...), .version(...), .built_at(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of ProviderStatus.