#[non_exhaustive]pub enum NotebookFocus {
None,
Collapsed(FocusPosition),
Selection {
anchor: FocusPosition,
focus: FocusPosition,
},
}Expand description
Specifies the user’s focus and optional selection within the notebook.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
The user has no focus within the notebook.
Collapsed(FocusPosition)
The user focus is within the notebook and the focus is on a single position. I.e. there is no selection.
Selection
The user has a selection within the notebook that started at the given anchor position and ends at the given focus position.
Implementations
Sourceimpl NotebookFocus
impl NotebookFocus
pub fn anchor_cell_id(&self) -> Option<&str>
pub fn anchor_cell_index(&self, cell_ids: &[&str]) -> Option<usize>
pub fn anchor_field(&self) -> Option<&str>
pub fn anchor_offset(&self) -> u32
pub fn anchor_position(&self) -> Option<&FocusPosition>
pub fn end_cell_id(&self, cell_ids: &[&str]) -> Option<&str>
pub fn end_offset(&self, cell_ids: &[&str]) -> u32
pub fn focus_cell_id(&self) -> Option<&str>
pub fn focus_cell_index(&self, cell_ids: &[&str]) -> Option<usize>
pub fn focus_field(&self) -> Option<&str>
pub fn focus_offset(&self) -> u32
pub fn focus_position(&self) -> Option<&FocusPosition>
pub fn has_selection(&self) -> bool
Sourcepub fn is_collapsed(&self) -> bool
pub fn is_collapsed(&self) -> bool
Returns whether the cursor position is collapsed, ie. the opposite of
has_selection().
pub fn is_none(&self) -> bool
pub fn start_cell_id(&self, cell_ids: &[&str]) -> Option<&str>
pub fn start_offset(&self, cell_ids: &[&str]) -> u32