#[non_exhaustive]pub enum RejectReason {
Show 18 variants
CellIndexOutOfBounds,
CellNotFound {
cell_id: String,
},
DuplicateCellId {
cell_id: String,
},
DuplicateLabel(DuplicateLabelRejectReason),
DuplicateTableId {
table_id: String,
},
FailedPrecondition {
message: String,
},
InvalidLabel(InvalidLabelRejectReason),
InconsistentState,
InvalidTableColumnIndex,
InvalidTableRowIndex,
InvalidTableDimensions,
InvalidTableId {
table_id: String,
},
InconsistentFrontMatter {
message: String,
},
InvalidFrontMatterUpdate(InvalidFrontMatterRejectReason),
NoTableCell {
cell_id: String,
},
NoTextCell {
cell_id: String,
},
Outdated(OutdatedRejectReason),
UnknownOperation {
operation_summary: String,
},
}Expand description
Reason why the apply operation was rejected.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CellIndexOutOfBounds
The operation referenced an invalid cell index.
CellNotFound
The operation referenced a non-existing cell.
DuplicateCellId
The operation tried to insert a cell with a non-unique ID.
DuplicateLabel(DuplicateLabelRejectReason)
A label was submitted for already exists for the notebook.
DuplicateTableId
The operation tried to insert a table row or column with a non-unique ID.
FailedPrecondition
The operation failed some miscellaneous precondition.
InvalidLabel(InvalidLabelRejectReason)
A label was submitted that was invalid.
InconsistentState
Current notebook state does not match old state in operation.
InvalidTableColumnIndex
A table operation specified a column index that is out of bounds.
InvalidTableRowIndex
A table operation specified a row index that is out of bounds.
InvalidTableDimensions
A table operation specified values that didn’t match the expected amount of columns or rows.
InvalidTableId
A table operation tried to reference a row or column with a non-existing ID.
InconsistentFrontMatter
Current notebook state does not match old state in operation.
InvalidFrontMatterUpdate(InvalidFrontMatterRejectReason)
The front matter updates in the operation does not apply cleanly to the notebook.
The most common occurrence of this will be trying to insert/modify values that don’t match the schema given in the operation.
NoTableCell
Attempted to perform a table operation on a non-table cell.
NoTextCell
Attempted to perform a text operation on a non-text cell.
Outdated(OutdatedRejectReason)
The requested apply operation was for an old version.
UnknownOperation
The operation is unknown, and cannot be validated.