#[non_exhaustive]pub struct ApplyOperationBatchMessage {
pub notebook_id: String,
pub operations: Vec<Operation>,
pub revision: u32,
pub op_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notebook_id: StringID of the notebook.
operations: Vec<Operation>The operations to apply.
revision: u32The revision assigned to the operation.
If a client sends this message, it requests this revision to be assigned and the operations may be rejected if the revision is already assigned.
When a client receives this message, it is the actual revision.
op_id: Option<String>Operation ID.
Only messages with an operation ID will receive an Ack from the
server.
Implementations
Sourceimpl ApplyOperationBatchMessage
impl ApplyOperationBatchMessage
Sourcepub fn builder() -> ApplyOperationBatchMessageBuilder<((), (), (), ())>
pub fn builder() -> ApplyOperationBatchMessageBuilder<((), (), (), ())>
Create a builder for building ApplyOperationBatchMessage.
On the builder, call .notebook_id(...), .operations(...), .revision(...), .op_id(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of ApplyOperationBatchMessage.