#[non_exhaustive]pub struct MentionMessage {
pub notebook_id: String,
pub cell_id: String,
pub mentioned_by: MentionedBy,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notebook_id: StringID of the notebook in which the user was mentioned.
cell_id: StringID of the cell in which the user was mentioned.
mentioned_by: MentionedByWho mentioned the user?
Implementations