#[non_exhaustive]pub struct SubscribeMessage {
pub notebook_id: String,
pub revision: Option<u32>,
pub op_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notebook_id: StringID of the notebook.
revision: Option<u32>The current revision that the client knows about. If this is not the current revision according to the server, than the server will sent all operations starting from this revision.
op_id: Option<String>Operation ID.
Only messages with an operation ID will receive an Ack from the
server.
Implementations