#[non_exhaustive]pub struct SubscriberAddedMessage {
pub notebook_id: String,
pub session_id: String,
pub created_at: Timestamp,
pub updated_at: Timestamp,
pub user: User,
pub focus: NotebookFocus,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notebook_id: StringThe ID of the notebook that the user subscribed to.
session_id: StringID associated with the newly connected session. There can be multiple sessions for a single (notebook|user) pair. The ID can be used multiple times for different (notebook|user) pairs. The combination of notebook, user and session will be unique.
created_at: TimestampThe moment the session was created.
updated_at: TimestampThe last time the user was active in this session.
user: UserUser details associated with the session.
focus: NotebookFocusUser’s focus within the notebook.
Implementations
sourceimpl SubscriberAddedMessage
impl SubscriberAddedMessage
sourcepub fn builder() -> SubscriberAddedMessageBuilder<((), (), (), (), (), ())>
pub fn builder() -> SubscriberAddedMessageBuilder<((), (), (), (), (), ())>
Create a builder for building SubscriberAddedMessage.
On the builder, call .notebook_id(...), .session_id(...), .created_at(...), .updated_at(...), .user(...), .focus(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of SubscriberAddedMessage.