BindgenSerializable

Trait BindgenSerializable 

pub trait BindgenSerializable { }
Helper trait to use as a trait bound on generic types that must be serializable when the fp-bindgen feature is enabled

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> BindgenSerializable for T

Available on non-crate feature fp-bindgen only.