#[non_exhaustive]pub struct RemoveTableColumnOperation {
pub cell_id: String,
pub column_def: TableColumnDefinition,
pub index: u32,
pub values: Vec<TableRowValue>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cell_id: StringID of the table cell.
column_def: TableColumnDefinitionDefinition of the column being removed.
index: u32The index of the column being removed.
values: Vec<TableRowValue>The values that are being removed together with the column.
The amount of values should match the amount of rows in the table.
Implementations
Sourceimpl RemoveTableColumnOperation
impl RemoveTableColumnOperation
Sourcepub fn builder() -> RemoveTableColumnOperationBuilder<((), (), (), ())>
pub fn builder() -> RemoveTableColumnOperationBuilder<((), (), (), ())>
Create a builder for building RemoveTableColumnOperation.
On the builder, call .cell_id(...), .column_def(...), .index(...), .values(...) to set the values of the fields.
Finally, call .build() to create the instance of RemoveTableColumnOperation.