pub type QuerySchema = Vec<QueryField>;Expand description
Defines the fields that should be included in the query data.
Query data is encoded as “application/x-www-form-urlencoded”, unless a
File field is present in the schema, in which case “multipart/form-data”
may be used.
Aliased Type
pub struct QuerySchema { /* private fields */ }