pub trait BindgenSerializable { }Expand description
Helper trait to use as a trait bound on generic types that must be serializable when
the fp-bindgen feature is enabled
pub trait BindgenSerializable { }Helper trait to use as a trait bound on generic types that must be serializable when
the fp-bindgen feature is enabled